@@ -1,6 +1,6 @@
 package Text::Todo::Simple::Command::remove;
 BEGIN {
-  $Text::Todo::Simple::Command::remove::VERSION = '0.15';
+  $Text::Todo::Simple::Command::remove::VERSION = '0.16';
 }
 
 use Text::Todo::Simple -command;
@@ -14,7 +14,7 @@ Text::Todo::Simple::Command::remove - Remove a task
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 SYNOPSIS
 
@@ -30,6 +30,8 @@ sub usage_desc {
 	return '%c remove %o id';
 }
 
+sub command_names { qw/remove rm --remove -r/ }
+
 sub execute {
 	my ($self, $opt, $args) = @_;
 
@@ -46,10 +48,6 @@ sub execute {
 	print "Removed task '$id'\n";
 }
 
-=head1 OPTIONS
-
-
-
 =head1 AUTHOR
 
 Alessandro Ghedini <alexbio@cpan.org>
